@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: generate.sh,v 1.1 2003/08/28 20:21:04 peter Exp $
+# $Id: generate.sh,v 1.2 2007/06/02 09:03:09 peter Exp $
 
 if [ -z "$1" ]; then
 	file_sgml="ipv6calc.sgml"
@@ -12,9 +12,9 @@ echo "Used SGML file: $file_sgml"
 
 file_base="`basename $file_sgml .sgml`"
 
-file_html="$file_base.html"
+file_html="${file_base}.html"
 
-file_dsl="/usr/local/share/sgml/ldp.dsl"
+file_dsl="/usr/local/share/sgml/dsssl/ldp.dsl"
 
 if [ ! -f "$file_dsl" ]; then
 	echo "ERR: Missing DSL file: $file_dsl"
@@ -27,19 +27,13 @@ if [ ! -f $file_sgml ]; then
 	exit 1
 fi
 
-# run sgmlfix
-if [ -e ./runsgmlfix.sh ]; then
-	./runsgmlfix.sh "$file_sgml"
-else
-	echo "WARN: cannot execute 'runsgmlfix.sh'"
-fi
-
 validate_sgml() {
 	echo "INF: Validate SGML code '$file_sgml'"
 	set -x
-	nsgmls -s $file_sgml
+	onsgmls -s $file_sgml
+	local result=$?
 	set +x
-	if [ $? -gt 0 ]; then
+	if [ $result -gt 0 ]; then
 		echo "ERR: Validation results in errors!"
 		return 1
 	else
@@ -51,7 +45,7 @@ validate_sgml() {
 create_html_singlepage() {
 	echo "INF: Create HTML singlepage '$file_html'"
 	set -x
-	jade -t sgml -i html -V nochunks -d "/usr/local/share/sgml/ldp.dsl#html" $file_sgml >$file_html
+	jade -t sgml -i html -V nochunks -d "${file_dsl}#html" $file_sgml >$file_html
 	set +x
 	local retval=$?
 	if [ $retval -eq 0 ]; then
@@ -64,9 +58,6 @@ create_html_singlepage() {
 
 
 ### Main
-validate_sgml
-[ $? -ne 0 ] && exit 1
-
-create_html_singlepage
-[ $? -ne 0 ] && exit 1
+validate_sgml || exit 1
 
+create_html_singlepage || exit 1
